//////////////////////////////////////////////////////////
// Projectile Of Titan Friend - Magma Rock
// Creator: Rocky, Time: 9:57AM, Date: 20th June,2013
//////////////////////////////////////////////////////////
class MagmaBoulder extends Projectile;

#exec MESH IMPORT MESH=MagBoulder ANIVFILE=MODELS\MagBoulder_a.3d DATAFILE=MODELS\MagBoulder_d.3d X=0 Y=0 Z=0
#exec MESH ORIGIN MESH=MagBoulder X=0 Y=0 Z=0

#exec MESH SEQUENCE MESH=MagBoulder SEQ=All STARTFRAME=0 NUMFRAMES=65
//#exec MESH SEQUENCE MESH=MagBoulder SEQ=??? STARTFRAME=0 NUMFRAMES=65

#exec MESHMAP NEW MESHMAP=MagBoulder MESH=MagBoulder
#exec MESHMAP SCALE MESHMAP=MagBoulder X=0.1 Y=0.1 Z=0.2

#exec TEXTURE IMPORT NAME=Magma FILE=Textures\MagmaBoulder.PCX GROUP="Skins" LODSET=2
#exec MESHMAP SETTEXTURE MESHMAP=MagBoulder NUM=1 TEXTURE=Magma

var MagmaTrail Trail;
var float SmokeRate;
var bool bRing,bHitWater,bWaterStart;
var vector InitialDir;

function PostBeginPlay()
{
	Trail = Spawn(class'MagmaTrail',self);
	if ( Level.bHighDetailMode )
	{
		SmokeRate = (200 + (0.5 + 2 * FRand()) * 24)/Speed; 
		if ( Level.bDropDetail )
		{
			SoundRadius = 64;
			LightRadius = 128;
		}
	}
	else 
	{
		SmokeRate = 0.15 + FRand();
		LightRadius = 64;
	}
	SetTimer(SmokeRate, true);
}

simulated function Destroyed()
{
	if ( Trail != None )
		Trail.Destroy();
	Super.Destroyed();
}

auto state Flying
{

	simulated function ZoneChange( Zoneinfo NewZone )
	{
		local waterring w;
		
		if (!NewZone.bWaterZone || bHitWater) Return;

		bHitWater = True;
		if ( Level.NetMode != NM_DedicatedServer )
		{
			w = Spawn(class'WaterRing',,,,rot(16384,0,0));
			w.DrawScale = 0.2;
			w.RemoteRole = ROLE_None;
			PlayAnim( 'All', 3.0 );
		}		
		Velocity=0.6*Velocity;
	}
	
	function BeginState()
	{
		local vector Dir;

		Dir = vector(Rotation);
		Velocity = speed * Dir;
		Acceleration = Dir * 50;
		PlayAnim( 'All', 0.2 );
		if (Region.Zone.bWaterZone)
		{
			bHitWater = True;
			Velocity=0.6*Velocity;
		}
	}
	
	simulated function ProcessTouch (Actor Other, Vector HitLocation)
	{
		if ( (Other != instigator) && !Other.IsA('Projectile') ) 
			Explode(HitLocation,Normal(HitLocation-Other.Location));
	}
	
	function BlowUp(vector HitLocation)
	{
		HurtRadius(Damage,220.0, MyDamageType, MomentumTransfer, HitLocation );
		MakeNoise(1.0);
	}

	simulated function Explode(vector HitLocation, vector HitNormal)
	{
		local MagmaExplo s;

		s = spawn(class'MagmaExplo',,,HitLocation + HitNormal*16);	
 		s.RemoteRole = ROLE_None;
		BlowUp(HitLocation);
		Destroy();
	}

}

simulated function Timer()
{
	local ut_SpriteSmokePuff b;

	if ( Region.Zone.bWaterZone || (Level.NetMode == NM_DedicatedServer) )
		Return;

	if ( Level.bHighDetailMode )
	{
		Spawn(class'UTSmokeTrail'); 
	}
	else 
	{
		b = Spawn(class'ut_SpriteSmokePuff');
		b.RemoteRole = ROLE_None;
	}
}

defaultproperties
{
	speed=850.000000
    Damage=300.000000
	Mesh=LodMesh'UT99OrgMW.MagBoulder'
	DrawScale=1.300000
	MultiSkins(0)=Texture'UT99OrgMW.Skins.Magma'
	ExplosionDecal=Class'NuclearMark'
	AmbientSound=Sound'AmdAncient.Looping.LavaF1'
	LightBrightness=153
	LightHue=14
	LightSaturation=95
	SoundRadius=255
    SoundVolume=255
    SoundPitch=48
	CollisionRadius=3.000000
    CollisionHeight=3.000000
